@@ -41,8 +41,16 @@ void Controller::toggleState() {
 
 QString Controller::getLanguage() {
     QMap<QString, QString> langs;
-    langs["German"] = "de";
-    langs["Deutsch"] = "de";
+
+    QString english(tr("English"));
+    QString german(tr("German"));
+    QString italian(tr("Italian"));
+    QString finnish(tr("Finnish"));
+
+    langs[english] = "en";
+    langs[german] = "de";
+    langs[italian] = "it";
+    langs[finnish] = "fi";
 
     QString langCode = "en";
 
@@ -91,6 +99,25 @@ void Controller::setMediaPlayer(const QString &player) {
     mediaPlayer = player.toLower().replace(" ", "");
 }
 
+void Controller::getMediaPlayerFromDB() {
+    QSqlDatabase db;
+    db = QSqlDatabase::addDatabase("QSQLITE");
+    db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
+    db.open();
+
+    QSqlQuery query("select value from settings where setting = 'mediaPlayer'");
+    QSqlRecord record = query.record();
+    QString player = "Media Player";
+
+    if (record.count() > 0) {
+        while (query.next()) {
+            player = query.value(0).toString();
+        }
+//        qDebug() << player;
+    }
+    setMediaPlayer(player);
+}
+
 bool Controller::kmPlayerInstalled() {
     bool isInstalled = false;
     if ((QFile::exists("/opt/kmplayer/bin/kmplayer")) || (QFile::exists("/usr/bin/kmplayer"))) {
@@ -114,6 +141,7 @@ void Controller::playVideo(const QString &url) {
     QDBusConnection bus = QDBusConnection::sessionBus();
     QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
     dbus_iface.call("mime_open", url);
+    emit playbackStarted();
 #endif
 }
 
