@@ -23,6 +23,7 @@ public slots:
     bool kmPlayerInstalled();
     bool xTubeInstalled();
     void setMediaPlayer(const QString &player);
+    void getMediaPlayerFromDB();
     void toggleState();
     void minimize();
     void playVideo(const QString &url);
@@ -47,6 +48,7 @@ signals:
     void conversionStarted();
     void conversionCompleted();
     void conversionFailed();
+    void playbackStarted();
 };
 
 #endif // CONTROLLER_H
