@@ -6,7 +6,7 @@
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.5.1</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -71,17 +71,17 @@
     <message>
         <location filename="../AddCommentDialog.qml" line="60"/>
         <source>Title</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../AddCommentDialog.qml" line="87"/>
         <source>Description</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../AddCommentDialog.qml" line="124"/>
         <source>Message</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -167,24 +167,44 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="123"/>
+        <location filename="../../../controller.cpp" line="45"/>
+        <source>English</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="46"/>
+        <source>German</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="47"/>
+        <source>Italian</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="48"/>
+        <source>Finnish</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="131"/>
         <source>Video deleted from device</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="126"/>
+        <location filename="../../../controller.cpp" line="134"/>
         <source>Unable to delete video</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="130"/>
+        <location filename="../../../controller.cpp" line="138"/>
         <source>Video not found</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="185"/>
+        <location filename="../../../controller.cpp" line="193"/>
         <source>Copied to clipboard</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -192,22 +212,22 @@
     <message>
         <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Queued</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../DownloadListDelegate.qml" line="49"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../DownloadListDelegate.qml" line="66"/>
         <source>Downloading</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -217,17 +237,17 @@
         <location filename="../../../downloadmanager.cpp" line="66"/>
         <location filename="../../../downloadmanager.cpp" line="159"/>
         <source>Failed</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../downloadmanager.cpp" line="121"/>
         <source>Downloading</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../downloadmanager.cpp" line="156"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -297,42 +317,42 @@
 <context>
     <name>MyAccountView</name>
     <message>
-        <location filename="../MyAccountView.qml" line="75"/>
+        <location filename="../MyAccountView.qml" line="72"/>
         <source>Upload video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="115"/>
+        <location filename="../MyAccountView.qml" line="112"/>
         <source>My Uploads</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="121"/>
+        <location filename="../MyAccountView.qml" line="118"/>
         <source>Uploads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="139"/>
+        <location filename="../MyAccountView.qml" line="136"/>
         <source>My Favourites</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="145"/>
+        <location filename="../MyAccountView.qml" line="142"/>
         <source>Favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="169"/>
+        <location filename="../MyAccountView.qml" line="166"/>
         <source>Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="193"/>
+        <location filename="../MyAccountView.qml" line="190"/>
         <source>Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="208"/>
+        <location filename="../MyAccountView.qml" line="205"/>
         <source>Signed in as:</source>
         <translation></translation>
     </message>
@@ -401,17 +421,17 @@
     <message>
         <location filename="../OAuthDialog.qml" line="8"/>
         <source>Authorisation For </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../OAuthDialog.qml" line="27"/>
         <source>Error obtaining facebook authorisation</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../OAuthDialog.qml" line="117"/>
         <source>Enter pin code</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -484,24 +504,24 @@
         <location filename="../SearchBar.qml" line="116"/>
         <location filename="../SearchBar.qml" line="126"/>
         <source>Date</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="117"/>
         <location filename="../SearchBar.qml" line="119"/>
         <source>Relevance</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="120"/>
         <location filename="../SearchBar.qml" line="122"/>
         <source>Rating</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="123"/>
         <source>Views</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SearchBar.qml" line="176"/>
@@ -561,7 +581,7 @@
         <location filename="../SettingsDialog.qml" line="268"/>
         <location filename="../SettingsDialog.qml" line="422"/>
         <source>Language</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="95"/>
@@ -598,95 +618,105 @@
         <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
         <source>Mobile</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
         <source>High Quality</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="18"/>
         <location filename="../SettingsDialog.qml" line="36"/>
         <location filename="../SettingsDialog.qml" line="62"/>
         <source>Automatically</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="18"/>
         <location filename="../SettingsDialog.qml" line="39"/>
         <source>Manually</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
         <source>Automatic</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
         <source>Landscape</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="19"/>
         <source>Portrait</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="21"/>
         <source>Light</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="21"/>
         <source>Dark</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="22"/>
         <source>English</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="22"/>
         <source>German</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <source>Finnish</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <source>Italian</source>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="35"/>
         <location filename="../SettingsDialog.qml" line="63"/>
         <source>Queued</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="66"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="69"/>
         <source>Your settings have been saved</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="74"/>
         <location filename="../SettingsDialog.qml" line="104"/>
         <source>Download Path</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="76"/>
         <source>Download Location</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="113"/>
         <location filename="../SettingsDialog.qml" line="259"/>
         <location filename="../SettingsDialog.qml" line="404"/>
         <source>Theme</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="436"/>
@@ -699,24 +729,24 @@
     <message>
         <location filename="../../../sharing.cpp" line="78"/>
         <source>Error - Server repsonse is: </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>SubscriptionsView</name>
     <message>
-        <location filename="../SubscriptionsView.qml" line="48"/>
+        <location filename="../SubscriptionsView.qml" line="46"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="107"/>
-        <location filename="../SubscriptionsView.qml" line="122"/>
+        <location filename="../SubscriptionsView.qml" line="105"/>
+        <location filename="../SubscriptionsView.qml" line="120"/>
         <source>Latest Subscription Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="135"/>
+        <location filename="../SubscriptionsView.qml" line="133"/>
         <source>No subscriptions found</source>
         <translation></translation>
     </message>
@@ -847,7 +877,7 @@
     <message>
         <location filename="../UploadProgressDialog.qml" line="6"/>
         <source>Starting upload</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../UploadProgressDialog.qml" line="30"/>
@@ -879,18 +909,18 @@
         <location filename="../UploadProgressDialog.qml" line="97"/>
         <location filename="../UploadProgressDialog.qml" line="115"/>
         <source>Upload is in progress</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="120"/>
+        <location filename="../UserInfoDialog.qml" line="127"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="134"/>
+        <location filename="../UserInfoDialog.qml" line="141"/>
         <source>Videos</source>
         <translation></translation>
     </message>
@@ -898,67 +928,67 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="84"/>
+        <location filename="../UserVideosView.qml" line="98"/>
         <source>You have subscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="88"/>
+        <location filename="../UserVideosView.qml" line="102"/>
         <source>You have unsubscribed to &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="110"/>
+        <location filename="../UserVideosView.qml" line="124"/>
         <source>Multi-select</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="112"/>
+        <location filename="../UserVideosView.qml" line="126"/>
         <source>Download video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="112"/>
+        <location filename="../UserVideosView.qml" line="126"/>
         <source>Download audio</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="113"/>
+        <location filename="../UserVideosView.qml" line="127"/>
         <source>Add to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="113"/>
+        <location filename="../UserVideosView.qml" line="127"/>
         <source>Add to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="113"/>
+        <location filename="../UserVideosView.qml" line="127"/>
         <source>Copy to clipboard</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="166"/>
+        <location filename="../UserVideosView.qml" line="180"/>
         <source>No videos found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="218"/>
+        <location filename="../UserVideosView.qml" line="239"/>
         <source>Subscribers</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="232"/>
+        <location filename="../UserVideosView.qml" line="253"/>
         <source>Videos</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="255"/>
+        <location filename="../UserVideosView.qml" line="276"/>
         <source>Unsubscribe</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="255"/>
+        <location filename="../UserVideosView.qml" line="276"/>
         <source>Subscribe</source>
         <translation></translation>
     </message>
@@ -983,7 +1013,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="81"/>
         <source>Video shared on facebook</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="103"/>
@@ -1003,7 +1033,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="104"/>
         <source>Share via facebook</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="123"/>
@@ -1081,7 +1111,7 @@
     <message>
         <location filename="../VideoListDelegate.qml" line="102"/>
         <source>Views</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -1127,7 +1157,114 @@
     <message>
         <location filename="../VideoPlaybackView.qml" line="60"/>
         <source>Error: Unable to retrieve video</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
+    </message>
+</context>
+<context>
+    <name>Widget</name>
+    <message>
+        <location filename="../Widget.qml" line="81"/>
+        <source>Error: Unable to retrieve video</source>
+        <translation></translation>
+    </message>
+</context>
+<context>
+    <name>XHamsterInfoView</name>
+    <message>
+        <location filename="../XHamsterInfoView.qml" line="211"/>
+        <source>Info</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterInfoView.qml" line="250"/>
+        <source>Related</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterInfoView.qml" line="332"/>
+        <location filename="../XHamsterInfoView.qml" line="335"/>
+        <source>By </source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterInfoView.qml" line="334"/>
+        <location filename="../XHamsterInfoView.qml" line="337"/>
+        <source> on </source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterInfoView.qml" line="353"/>
+        <source>Views </source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterInfoView.qml" line="359"/>
+        <source>Tags</source>
+        <translation></translation>
+    </message>
+</context>
+<context>
+    <name>XHamsterListView</name>
+    <message>
+        <location filename="../XHamsterListView.qml" line="148"/>
+        <source>Multi-select</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterListView.qml" line="150"/>
+        <source>Download video</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../XHamsterListView.qml" line="186"/>
+        <source>No videos found</source>
+        <translation></translation>
+    </message>
+</context>
+<context>
+    <name>YouJizzInfoView</name>
+    <message>
+        <location filename="../YouJizzInfoView.qml" line="65"/>
+        <source>Copy to clipboard</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../YouJizzInfoView.qml" line="200"/>
+        <source>Info</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../YouJizzInfoView.qml" line="239"/>
+        <source>Related</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../YouJizzInfoView.qml" line="316"/>
+        <source>Views </source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../YouJizzInfoView.qml" line="322"/>
+        <source>Tags</source>
+        <translation></translation>
+    </message>
+</context>
+<context>
+    <name>YouJizzListView</name>
+    <message>
+        <location filename="../YouJizzListView.qml" line="135"/>
+        <source>Multi-select</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../YouJizzListView.qml" line="137"/>
+        <source>Download video</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../YouJizzListView.qml" line="173"/>
+        <source>No videos found</source>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -1135,121 +1272,121 @@
     <message>
         <location filename="../../../youtube.cpp" line="39"/>
         <source>Error obtaining access token</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="49"/>
         <source>Authentication failed</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../../../youtube.cpp" line="52"/>
         <source>You are signed in to YouTube as &apos;</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="114"/>
-        <location filename="../../../youtube.cpp" line="220"/>
+        <location filename="../../../youtube.cpp" line="115"/>
+        <location filename="../../../youtube.cpp" line="221"/>
         <source>Error - Server repsonse is: </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="172"/>
+        <location filename="../../../youtube.cpp" line="165"/>
+        <location filename="../../../youtube.cpp" line="173"/>
         <source>Upload aborted</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="180"/>
         <source>Upload interrupted. Attempting to resume...</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="183"/>
+        <location filename="../../../youtube.cpp" line="184"/>
         <source>Upload failed</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="189"/>
+        <location filename="../../../youtube.cpp" line="190"/>
         <source>Upload is completed</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="379"/>
+        <location filename="../../../youtube.cpp" line="383"/>
         <source>Error: Unable to retrieve video</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="12"/>
-        <location filename="../main.qml" line="15"/>
-        <location filename="../main.qml" line="16"/>
-        <location filename="../main.qml" line="17"/>
         <location filename="../main.qml" line="18"/>
+        <location filename="../main.qml" line="21"/>
+        <location filename="../main.qml" line="22"/>
+        <location filename="../main.qml" line="23"/>
+        <location filename="../main.qml" line="24"/>
         <source>Dark</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="103"/>
+        <location filename="../main.qml" line="109"/>
         <source>Video(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="114"/>
+        <location filename="../main.qml" line="120"/>
         <source>Audio track(s) added to download queue</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="145"/>
+        <location filename="../main.qml" line="151"/>
         <source>Video added to favourites</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="146"/>
+        <location filename="../main.qml" line="152"/>
         <source>Video added to playlist</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="159"/>
         <source>New playlist created</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="193"/>
+        <location filename="../main.qml" line="199"/>
         <source>Converting</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="202"/>
+        <location filename="../main.qml" line="208"/>
         <source>Conversion of &apos;</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="202"/>
+        <location filename="../main.qml" line="208"/>
         <source>&apos; failed</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="216"/>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="263"/>
+        <location filename="../main.qml" line="222"/>
+        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="269"/>
         <source>Queued</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="231"/>
+        <location filename="../main.qml" line="237"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="411"/>
+        <location filename="../main.qml" line="414"/>
         <source>Most Recent</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="412"/>
+        <location filename="../main.qml" line="415"/>
         <source>Most Viewed</source>
         <translation></translation>
     </message>
@@ -1259,67 +1396,67 @@
     <message>
         <location filename="../scripts/mainscripts.js" line="19"/>
         <source>Media Player</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="119"/>
         <source>My Channel</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="133"/>
         <source>Archive</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="172"/>
         <source>My Playlists</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="182"/>
         <source>My Subscriptions</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="195"/>
         <source>Video Info</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="204"/>
         <source>Video Playback</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="214"/>
         <source>Downloads</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="222"/>
         <source>date</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="225"/>
         <source>views</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="228"/>
         <source>relevance</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="231"/>
         <source>rating</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/mainscripts.js" line="237"/>
         <source>Search </source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
 </context>
 <context>
@@ -1328,37 +1465,73 @@
         <location filename="../scripts/settings.js" line="126"/>
         <location filename="../scripts/settings.js" line="127"/>
         <source>High Quality</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="128"/>
         <source>Paused</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="130"/>
         <source>Automatic</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="131"/>
         <source>Media Player</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="132"/>
         <source>Date</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="133"/>
         <source>Dark</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../scripts/settings.js" line="134"/>
         <source>English</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
+    </message>
+</context>
+<context>
+    <name>xtube</name>
+    <message>
+        <location filename="../scripts/xtube.js" line="7"/>
+        <location filename="../scripts/xtube.js" line="57"/>
+        <source>date</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="10"/>
+        <source>views</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="13"/>
+        <source>rating</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="18"/>
+        <location filename="../scripts/xtube.js" line="62"/>
+        <source>Search </source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="39"/>
+        <location filename="../scripts/xtube.js" line="82"/>
+        <source>Video Info</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="57"/>
+        <source>relevance</source>
+        <translation></translation>
     </message>
 </context>
 </TS>
