@@ -215,22 +215,42 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="123"/>
+        <location filename="../../../controller.cpp" line="45"/>
+        <source>English</source>
+        <translation>Englisch</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="46"/>
+        <source>German</source>
+        <translation>Deutsch</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="47"/>
+        <source>Italian</source>
+        <translation>Italienisch</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="48"/>
+        <source>Finnish</source>
+        <translation>Finnisch</translation>
+    </message>
+    <message>
+        <location filename="../../../controller.cpp" line="131"/>
         <source>Video deleted from device</source>
         <translation>Video vom Gerät gelöscht</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="126"/>
+        <location filename="../../../controller.cpp" line="134"/>
         <source>Unable to delete video</source>
         <translation>Löschen des Videos nicht möglich</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="130"/>
+        <location filename="../../../controller.cpp" line="138"/>
         <source>Video not found</source>
         <translation>Video nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="185"/>
+        <location filename="../../../controller.cpp" line="193"/>
         <source>Copied to clipboard</source>
         <translation>In Zwischenablage kopiert</translation>
     </message>
@@ -349,42 +369,42 @@
 <context>
     <name>MyAccountView</name>
     <message>
-        <location filename="../MyAccountView.qml" line="75"/>
+        <location filename="../MyAccountView.qml" line="72"/>
         <source>Upload video</source>
         <translation>Video hochladen</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="115"/>
+        <location filename="../MyAccountView.qml" line="112"/>
         <source>My Uploads</source>
         <translation>Mein Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="121"/>
+        <location filename="../MyAccountView.qml" line="118"/>
         <source>Uploads</source>
         <translation>Uploads</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="139"/>
+        <location filename="../MyAccountView.qml" line="136"/>
         <source>My Favourites</source>
         <translation>Mein Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="145"/>
+        <location filename="../MyAccountView.qml" line="142"/>
         <source>Favourites</source>
         <translation>Favoriten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="169"/>
+        <location filename="../MyAccountView.qml" line="166"/>
         <source>Playlists</source>
         <translation>Wiedergabelisten</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="193"/>
+        <location filename="../MyAccountView.qml" line="190"/>
         <source>Subscriptions</source>
         <translation>Abonnement</translation>
     </message>
     <message>
-        <location filename="../MyAccountView.qml" line="208"/>
+        <location filename="../MyAccountView.qml" line="205"/>
         <source>Signed in as:</source>
         <translation>Angemeldet als:</translation>
     </message>
@@ -710,6 +730,16 @@
         <source>German</source>
         <translation>Deutsch</translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <source>Finnish</source>
+        <translation>Finnisch</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <source>Italian</source>
+        <translation>Italienisch</translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="35"/>
         <location filename="../SettingsDialog.qml" line="63"/>
@@ -761,18 +791,18 @@
 <context>
     <name>SubscriptionsView</name>
     <message>
-        <location filename="../SubscriptionsView.qml" line="48"/>
+        <location filename="../SubscriptionsView.qml" line="46"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="107"/>
-        <location filename="../SubscriptionsView.qml" line="122"/>
+        <location filename="../SubscriptionsView.qml" line="105"/>
+        <location filename="../SubscriptionsView.qml" line="120"/>
         <source>Latest Subscription Videos</source>
         <translation>Letzte abonnierte Videos</translation>
     </message>
     <message>
-        <location filename="../SubscriptionsView.qml" line="135"/>
+        <location filename="../SubscriptionsView.qml" line="133"/>
         <source>No subscriptions found</source>
         <translation>Keine Abonnements gefunden</translation>
     </message>
@@ -949,12 +979,12 @@
 <context>
     <name>UserInfoDialog</name>
     <message>
-        <location filename="../UserInfoDialog.qml" line="120"/>
+        <location filename="../UserInfoDialog.qml" line="127"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserInfoDialog.qml" line="134"/>
+        <location filename="../UserInfoDialog.qml" line="141"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
@@ -962,67 +992,67 @@
 <context>
     <name>UserVideosView</name>
     <message>
-        <location filename="../UserVideosView.qml" line="84"/>
+        <location filename="../UserVideosView.qml" line="98"/>
         <source>You have subscribed to &apos;</source>
         <translation>Du hast ein Abonnement bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="88"/>
+        <location filename="../UserVideosView.qml" line="102"/>
         <source>You have unsubscribed to &apos;</source>
         <translation>Abonnement gekündigt bei</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="110"/>
+        <location filename="../UserVideosView.qml" line="124"/>
         <source>Multi-select</source>
         <translation>Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="112"/>
+        <location filename="../UserVideosView.qml" line="126"/>
         <source>Download video</source>
         <translation>Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="112"/>
+        <location filename="../UserVideosView.qml" line="126"/>
         <source>Download audio</source>
         <translation>Audio herrunterladen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="113"/>
+        <location filename="../UserVideosView.qml" line="127"/>
         <source>Add to favourites</source>
         <translation>Zu Favoriten hinzufügen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="113"/>
+        <location filename="../UserVideosView.qml" line="127"/>
         <source>Add to playlist</source>
         <translation>Zur Wiedergabeliste hinzufügen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="113"/>
+        <location filename="../UserVideosView.qml" line="127"/>
         <source>Copy to clipboard</source>
         <translation>In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="166"/>
+        <location filename="../UserVideosView.qml" line="180"/>
         <source>No videos found</source>
         <translation>Keine Videos gefunden</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="218"/>
+        <location filename="../UserVideosView.qml" line="239"/>
         <source>Subscribers</source>
         <translation>Abonnenten</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="232"/>
+        <location filename="../UserVideosView.qml" line="253"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="255"/>
+        <location filename="../UserVideosView.qml" line="276"/>
         <source>Unsubscribe</source>
         <translation>Abonnement kündigen</translation>
     </message>
     <message>
-        <location filename="../UserVideosView.qml" line="255"/>
+        <location filename="../UserVideosView.qml" line="276"/>
         <source>Subscribe</source>
         <translation>Abonnieren</translation>
     </message>
@@ -1194,84 +1224,111 @@
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
 </context>
+<context>
+    <name>Widget</name>
+    <message>
+        <location filename="../Widget.qml" line="81"/>
+        <source>Error: Unable to retrieve video</source>
+        <translation>Fehler: Kann Video nicht empfangen</translation>
+    </message>
+</context>
 <context>
     <name>XHamsterInfoView</name>
     <message>
+        <location filename="../XHamsterInfoView.qml" line="211"/>
         <source>Info</source>
-        <translation type="obsolete">Info</translation>
+        <translation>Info</translation>
     </message>
     <message>
+        <location filename="../XHamsterInfoView.qml" line="250"/>
         <source>Related</source>
-        <translation type="obsolete">Ähnliche</translation>
+        <translation>Ähnliche</translation>
     </message>
     <message>
+        <location filename="../XHamsterInfoView.qml" line="332"/>
+        <location filename="../XHamsterInfoView.qml" line="335"/>
         <source>By </source>
-        <translation type="obsolete">Von </translation>
+        <translation>Von </translation>
     </message>
     <message>
+        <location filename="../XHamsterInfoView.qml" line="334"/>
+        <location filename="../XHamsterInfoView.qml" line="337"/>
         <source> on </source>
-        <translation type="obsolete"> am </translation>
+        <translation> am </translation>
     </message>
     <message>
+        <location filename="../XHamsterInfoView.qml" line="353"/>
         <source>Views </source>
-        <translation type="obsolete">Aufrufe</translation>
+        <translation>Aufrufe</translation>
     </message>
     <message>
+        <location filename="../XHamsterInfoView.qml" line="359"/>
         <source>Tags</source>
-        <translation type="obsolete">Tags</translation>
+        <translation>Tags</translation>
     </message>
 </context>
 <context>
     <name>XHamsterListView</name>
     <message>
+        <location filename="../XHamsterListView.qml" line="148"/>
         <source>Multi-select</source>
-        <translation type="obsolete">Mehrfachauswahl</translation>
+        <translation>Mehrfachauswahl</translation>
     </message>
     <message>
+        <location filename="../XHamsterListView.qml" line="150"/>
         <source>Download video</source>
-        <translation type="obsolete">Video herrunterladen</translation>
+        <translation>Video herrunterladen</translation>
     </message>
     <message>
+        <location filename="../XHamsterListView.qml" line="186"/>
         <source>No videos found</source>
-        <translation type="obsolete">Keine Videos gefunden</translation>
+        <translation>Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
     <name>YouJizzInfoView</name>
     <message>
+        <location filename="../YouJizzInfoView.qml" line="65"/>
         <source>Copy to clipboard</source>
-        <translation type="obsolete">In Zwischenablage kopieren</translation>
+        <translation>In Zwischenablage kopieren</translation>
     </message>
     <message>
+        <location filename="../YouJizzInfoView.qml" line="200"/>
         <source>Info</source>
-        <translation type="obsolete">Info</translation>
+        <translation>Info</translation>
     </message>
     <message>
+        <location filename="../YouJizzInfoView.qml" line="239"/>
         <source>Related</source>
-        <translation type="obsolete">Ähnliche</translation>
+        <translation>Ähnliche</translation>
     </message>
     <message>
+        <location filename="../YouJizzInfoView.qml" line="316"/>
         <source>Views </source>
-        <translation type="obsolete">Aufrufe</translation>
+        <translation>Aufrufe</translation>
     </message>
     <message>
+        <location filename="../YouJizzInfoView.qml" line="322"/>
         <source>Tags</source>
-        <translation type="obsolete">Tags</translation>
+        <translation>Tags</translation>
     </message>
 </context>
 <context>
     <name>YouJizzListView</name>
     <message>
+        <location filename="../YouJizzListView.qml" line="135"/>
         <source>Multi-select</source>
-        <translation type="obsolete">Mehrfachauswahl</translation>
+        <translation>Mehrfachauswahl</translation>
     </message>
     <message>
+        <location filename="../YouJizzListView.qml" line="137"/>
         <source>Download video</source>
-        <translation type="obsolete">Video herrunterladen</translation>
+        <translation>Video herrunterladen</translation>
     </message>
     <message>
+        <location filename="../YouJizzListView.qml" line="173"/>
         <source>No videos found</source>
-        <translation type="obsolete">Keine Videos gefunden</translation>
+        <translation>Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
@@ -1292,34 +1349,34 @@
         <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="114"/>
-        <location filename="../../../youtube.cpp" line="220"/>
+        <location filename="../../../youtube.cpp" line="115"/>
+        <location filename="../../../youtube.cpp" line="221"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="164"/>
-        <location filename="../../../youtube.cpp" line="172"/>
+        <location filename="../../../youtube.cpp" line="165"/>
+        <location filename="../../../youtube.cpp" line="173"/>
         <source>Upload aborted</source>
         <translation>Upload abgebrochen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="179"/>
+        <location filename="../../../youtube.cpp" line="180"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="183"/>
+        <location filename="../../../youtube.cpp" line="184"/>
         <source>Upload failed</source>
         <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="189"/>
+        <location filename="../../../youtube.cpp" line="190"/>
         <source>Upload is completed</source>
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="379"/>
+        <location filename="../../../youtube.cpp" line="383"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1327,73 +1384,73 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="../main.qml" line="12"/>
-        <location filename="../main.qml" line="15"/>
-        <location filename="../main.qml" line="16"/>
-        <location filename="../main.qml" line="17"/>
         <location filename="../main.qml" line="18"/>
+        <location filename="../main.qml" line="21"/>
+        <location filename="../main.qml" line="22"/>
+        <location filename="../main.qml" line="23"/>
+        <location filename="../main.qml" line="24"/>
         <source>Dark</source>
         <translation>Dunkel</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="103"/>
+        <location filename="../main.qml" line="109"/>
         <source>Video(s) added to download queue</source>
         <translation>Video(s) in Warteschlange eingefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="114"/>
+        <location filename="../main.qml" line="120"/>
         <source>Audio track(s) added to download queue</source>
         <translation>Audio Tracks in Warteschlange eingefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="145"/>
+        <location filename="../main.qml" line="151"/>
         <source>Video added to favourites</source>
         <translation>Video wurde zu Favoriten hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="146"/>
+        <location filename="../main.qml" line="152"/>
         <source>Video added to playlist</source>
         <translation>Video wurde zur Wiedergabeliste hinzugefügt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="153"/>
+        <location filename="../main.qml" line="159"/>
         <source>New playlist created</source>
         <translation>Neue Wiedergabeliste erstellt</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="193"/>
+        <location filename="../main.qml" line="199"/>
         <source>Converting</source>
         <translation>Konvertiere</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="202"/>
+        <location filename="../main.qml" line="208"/>
         <source>Conversion of &apos;</source>
         <translation>Unterhaltung zwischen &apos;</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="202"/>
+        <location filename="../main.qml" line="208"/>
         <source>&apos; failed</source>
         <translation>&apos; gescheitert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="216"/>
-        <location filename="../main.qml" line="223"/>
-        <location filename="../main.qml" line="263"/>
+        <location filename="../main.qml" line="222"/>
+        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="269"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="231"/>
+        <location filename="../main.qml" line="237"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="411"/>
+        <location filename="../main.qml" line="414"/>
         <source>Most Recent</source>
         <translation>Aktuellste Videos</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="412"/>
+        <location filename="../main.qml" line="415"/>
         <source>Most Viewed</source>
         <translation>Meistgesehen</translation>
     </message>
@@ -1508,12 +1565,37 @@
 <context>
     <name>xtube</name>
     <message>
-        <source>Search </source>
-        <translation type="obsolete">Suche</translation>
+        <location filename="../scripts/xtube.js" line="7"/>
+        <location filename="../scripts/xtube.js" line="57"/>
+        <source>date</source>
+        <translation>datum</translation>
     </message>
     <message>
+        <location filename="../scripts/xtube.js" line="10"/>
+        <source>views</source>
+        <translation>aufrufe</translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="13"/>
+        <source>rating</source>
+        <translation>bewertung</translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="18"/>
+        <location filename="../scripts/xtube.js" line="62"/>
+        <source>Search </source>
+        <translation>Suche</translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="39"/>
+        <location filename="../scripts/xtube.js" line="82"/>
         <source>Video Info</source>
-        <translation type="obsolete">Video Info</translation>
+        <translation>Video Info</translation>
+    </message>
+    <message>
+        <location filename="../scripts/xtube.js" line="57"/>
+        <source>relevance</source>
+        <translation>relevanz</translation>
     </message>
 </context>
 </TS>
