@@ -46,7 +46,7 @@ public slots:
 
 private slots:
     void checkLogin();
-    void setCurrentUser(const QString &user);
+    void setCurrentUser(const QString &user, const QString &pass);
     void setAccessToken(const QByteArray &token);
     void setUploadUrl();
     void performVideoUpload();
@@ -66,12 +66,13 @@ private:
     QByteArray developerKey;
     QString accessToken;
     QString currentUser;
+    QString currentUserPass;
     int playbackFormat;
     QHash<QString, int> pbMap;
     QString message;
 
 signals:
-    void gotVideoUrl(const QByteArray &videoUrl);
+    void gotVideoUrl(const QString &videoUrl);
     void videoUrlError();
     void alert(const QString &message);
     void currentUserChanged();
